==> kwifimanager-1.0.0-1.tar.gz: kwifimanager-1.0.0/kwifimanager/statistics.cpp <==
/***************************************************************************
                          statistics.cpp  -  description
                             -------------------
    begin                : Mon Aug 19 2002
    copyright            : (C) 2002 by Stefan Winter
    email                : mail@stefan-winter.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qwidget.h>
#include <qpainter.h>
#include <klocale.h>
#include "statistics.h"
#include "stuff.h"

Statistics::Statistics (statistical_data input):QWidget (0, "KWiFiManager")
{
  this->setCaption (i18n ("Statistics - KWiFiManager"));
  drawdata=input;
}

void
Statistics::paintEvent (QPaintEvent *)
{
  statpainter = new QPainter (this);
  QColor farbe (255, 255, 255);
  statpainter->drawText (40, 30, i18n ("Noise/Signal Level Statistics"));
  statpainter->drawText (150, 260, i18n ("BLUE = signal level, RED = noise level"));
  statpainter->drawText (25, 50, "0");
  statpainter->drawText (5, 234, "-102");
  statpainter->drawText (5, 250, i18n ("[dBm]"));
  statpainter->drawLine (41, 244, 41, 260);
  statpainter->drawLine (520, 244, 520, 260);
  statpainter->drawText (21, 274, i18n ("-240 s"));
  statpainter->drawText (510, 274, i18n ("now"));
  statpainter->fillRect (41, 41, 480, 204, farbe);
  QPointArray datensatz (240);
  QPointArray datensatz2 (240);
  int i = 0;
  for (int j = drawdata.current; j < drawdata.current + 240; j++)
    {
      datensatz.setPoint (i, 40 + (i * 2), 40 - (drawdata.sigLevel[j % 240] * 2));
      datensatz2.setPoint (i, 40 + (i * 2), 40 - (drawdata.noiseLevel[j % 240] * 2));
      i++;
    };
  statpainter->setPen (red);
  statpainter->drawPolyline (datensatz2, 1);
  statpainter->setPen (blue);
  statpainter->drawPolyline (datensatz, 1);
  delete statpainter;
}

==> kwifimanager-1.0.2.tar.gz: kwifimanager-1.0.2/kwifimanager/statistics.cpp <==
/***************************************************************************
                          statistics.cpp  -  description
                             -------------------
    begin                : Mon Aug 19 2002
    copyright            : (C) 2002 by Stefan Winter
    email                : mail@stefan-winter.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream>
#include <qwidget.h>
#include <qpainter.h>
#include <klocale.h>
#include "statistics.h"
#include "stuff.h"

Statistics::Statistics (statistical_data* input):QWidget (0, "KWiFiManager")
{
  this->setCaption (i18n ("Statistics - KWiFiManager"));
  drawdata=input;
}

void
Statistics::paintEvent (QPaintEvent *)
{
  statpainter = new QPainter (this);
  QColor farbe (255, 255, 255);
  statpainter->drawText (40, 30, i18n ("Noise/Signal Level Statistics"));
  statpainter->drawText (150, 260, i18n ("BLUE = signal level, RED = noise level"));
  statpainter->drawText (25, 50, "0");
  statpainter->drawText (5, 234, "-102");
  statpainter->drawText (5, 250, i18n ("[dBm]"));
  statpainter->drawLine (41, 244, 41, 260);
  statpainter->drawLine (520, 244, 520, 260);
  statpainter->drawText (21, 274, i18n ("-240 s"));
  statpainter->drawText (510, 274, i18n ("now"));
  statpainter->fillRect (41, 41, 480, 204, farbe);
  QPointArray datensatz (240);
  QPointArray datensatz2 (240);
  int i = 0;
  for (int j = drawdata->current; j < drawdata->current + 240; j++)
    {
      datensatz.setPoint (i, 40 + (i * 2), 40 - (drawdata->sigLevel[j % 240] * 2));
      datensatz2.setPoint (i, 40 + (i * 2), 40 - (drawdata->noiseLevel[j % 240] * 2));
      i++;
    };
  statpainter->setPen (red);
  statpainter->drawPolyline (datensatz2, 1);
  statpainter->setPen (blue);
  statpainter->drawPolyline (datensatz, 1);
  delete statpainter;
}
